crystal_toolkit.components.upload module — Crystal Toolkit documentation

# crystal_toolkit.components.upload module

class crystal_toolkit.components.upload.StructureMoleculeUploadComponent(default_data: MSONable | dict | str | None = None, id: str | None = None, links: dict[str, str] | None = None, storage_type: Literal['memory', 'local', 'session'] = 'memory', disable_callbacks: bool = False)

  Bases: `MPComponent`

  generate_callbacks(app, cache)

    Generate all callbacks associated with the layouts in this app. Assume that “suppress_callback_exceptions” is True, since it is not always guaranteed that all layouts will be displayed to the end user at all times, but it’s important the callbacks are defined on the server.